# pylidar2d
Python tools for 2d lidar

![img](https://raw.githubusercontent.com/danieldugas/pylidar2d/master/pylidar2d.png)

## Install

```
cd ~
git clone git@github.com:danieldugas/pylidar2d.git
cd pylidar2d
pip install .
```

## Run an Example

```
cd ~/pylidar2d/scripts
python clustering_example.py
```
